# Default storage for Mephisto Keypairs
This directory is used as the default storage for mephisto keypairs

you likely should never commit anything that is saved in this folder.

In the future, we will make it such that committing things in this folder will result in a failed commit.